# -*- coding: utf-8 -*-

from formats_common import *

enable = False
format = "GettextMo"
description = "Gettext Binary (mo)"
extensions = (".mo",)
singleFile = True
optionsProp = {}
